# paur
<p>
    <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/python-3.6+-blue.svg" alt="Python version" height="17"></a>
    <a href="https://github.com/tonybenoy/paur/blob/master/LICENSE"><img src="https://img.shields.io/github/license/tonybenoy/paur" alt="License" height="17"></a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Codestyle Black" height="17">
    </a>
</p>
<p>
    <a href="https://github.com/tonybenoy/paur/actions">
        <img src="https://github.com/tonybenoy/paur/workflows/mypy/badge.svg" alt="Test Status" height="20">
    </a>
</p>
Arch User Repository Helper for Arch Linux based on Python</br>.Install packages from Arch User Repository and Offical Repositories. Search for packages in AUR and Official Repositories. Uninstall locally installed packages. 
